@@ -1,10 +1,17 @@
 from . import config
-from .auth import ClusterAuth, KubeAuth, KubeConfig, InCluster
+from .auth import (
+    ClusterAuth,
+    KubeAuth,
+    KubeConfig,
+    InCluster,
+    AutoRefreshKubeConfigLoader,
+    AutoRefreshConfiguration,
+)
 from .core import KubeCluster
 from .helm import HelmCluster
 from .objects import make_pod_spec, make_pod_from_dict, clean_pod_template
 
-__all__ = [KubeCluster, HelmCluster]
+__all__ = ["HelmCluster", "KubeCluster"]
 
 from ._version import get_versions
 
