@@ -16,6 +16,7 @@ from distributed.utils import Log, Logs
 import kubernetes_asyncio as kubernetes
 from kubernetes_asyncio.client.rest import ApiException
 
+from .constants import KUBECLUSTER_WORKER_CONTAINER_NAME
 from .objects import (
     make_pod_from_dict,
     make_service_from_dict,
@@ -106,7 +107,9 @@ class Pod(ProcessInterface):
     async def logs(self):
         try:
             log = await self.core_api.read_namespaced_pod_log(
-                self._pod.metadata.name, self.namespace
+                self._pod.metadata.name,
+                self.namespace,
+                container=KUBECLUSTER_WORKER_CONTAINER_NAME,
             )
         except ApiException as e:
             if "waiting to start" in str(e):
@@ -165,12 +168,19 @@ class Scheduler(Pod):
         Set to 0 to disable the timeout (not recommended).
     """
 
-    def __init__(self, idle_timeout: str, service_wait_timeout_s: int = None, **kwargs):
+    def __init__(
+        self,
+        idle_timeout: str,
+        service_wait_timeout_s: int = None,
+        service_name_retries: int = None,
+        **kwargs
+    ):
         super().__init__(**kwargs)
         self.cluster._log("Creating scheduler pod on cluster. This may take some time.")
         self.service = None
         self._idle_timeout = idle_timeout
         self._service_wait_timeout_s = service_wait_timeout_s
+        self._service_name_retries = service_name_retries
         if self._idle_timeout is not None:
             self.pod_template.spec.containers[0].args += [
                 "--idle-timeout",
@@ -198,7 +208,9 @@ class Scheduler(Pod):
             port=SCHEDULER_PORT,
         )
         self.external_address = await get_external_address_for_scheduler_service(
-            self.core_api, self.service
+            self.core_api,
+            self.service,
+            service_name_resolution_retries=self._service_name_retries,
         )
 
         self.pdb = await self._create_pdb()
@@ -254,7 +266,7 @@ class Scheduler(Pod):
         pdb_template_dict = dask.config.get("kubernetes.scheduler-pdb-template")
         self.pdb_template = clean_pdb_template(make_pdb_from_dict(pdb_template_dict))
         self.pdb_template.metadata.name = self.cluster_name
-        self.pdb_template.spec.labels = copy.deepcopy(self.base_labels)
+        self.pdb_template.metadata.labels = copy.deepcopy(self.base_labels)
         self.pdb_template.spec.selector.match_labels[
             "dask.org/cluster-name"
         ] = self.cluster_name
@@ -329,6 +341,11 @@ class KubeCluster(SpecCluster):
         Timeout, in seconds, to wait for the remote scheduler service to be ready.
         Defaults to 30 seconds.
         Set to 0 to disable the timeout (not recommended).
+    scheduler_service_name_resolution_retries: int (optional)
+        Number of retries to resolve scheduler service name when running
+        from within the Kubernetes cluster.
+        Defaults to 20.
+        Must be set to 1 or greater.
     deploy_mode: str (optional)
         Run the scheduler as "local" or "remote".
         Defaults to ``"remote"``.
@@ -414,6 +431,7 @@ class KubeCluster(SpecCluster):
         dashboard_address=None,
         security=None,
         scheduler_service_wait_timeout=None,
+        scheduler_service_name_resolution_retries=None,
         scheduler_pod_template=None,
         **kwargs
     ):
@@ -425,6 +443,14 @@ class KubeCluster(SpecCluster):
         if isinstance(pod_template, dict):
             pod_template = make_pod_from_dict(pod_template)
 
+        if isinstance(scheduler_pod_template, str):
+            with open(scheduler_pod_template) as f:
+                scheduler_pod_template = dask.config.expand_environment_variables(
+                    yaml.safe_load(f)
+                )
+        if isinstance(scheduler_pod_template, dict):
+            scheduler_pod_template = make_pod_from_dict(scheduler_pod_template)
+
         self.pod_template = pod_template
         self.scheduler_pod_template = scheduler_pod_template
         self._generate_name = dask.config.get("kubernetes.name", override_with=name)
@@ -451,6 +477,10 @@ class KubeCluster(SpecCluster):
             "kubernetes.scheduler-service-wait-timeout",
             override_with=scheduler_service_wait_timeout,
         )
+        self._scheduler_service_name_resolution_retries = dask.config.get(
+            "kubernetes.scheduler-service-name-resolution-retries",
+            override_with=scheduler_service_name_resolution_retries,
+        )
         self.security = security
         if self.security and not isinstance(
             self.security, distributed.security.Security
@@ -577,6 +607,7 @@ class KubeCluster(SpecCluster):
                 "options": {
                     "idle_timeout": self._idle_timeout,
                     "service_wait_timeout_s": self._scheduler_service_wait_timeout,
+                    "service_name_retries": self._scheduler_service_name_resolution_retries,
                     "pod_template": self.scheduler_pod_template,
                     **common_options,
                 },
