@@ -20,9 +20,10 @@ from dask_kubernetes import (
     KubeConfig,
     KubeAuth,
 )
-from distributed.utils import tmpfile
+from dask.utils import tmpfile
 from distributed.utils_test import captured_logger
 
+from dask_kubernetes.constants import KUBECLUSTER_WORKER_CONTAINER_NAME
 
 TEST_DIR = os.path.abspath(os.path.join(__file__, ".."))
 CONFIG_DEMO = os.path.join(TEST_DIR, "config-demo.yaml")
@@ -123,7 +124,7 @@ async def test_logs(remote_cluster):
         await asyncio.sleep(0.1)
         assert time() < start + 20
 
-    logs = await cluster.logs()
+    logs = await cluster.get_logs()
     assert len(logs) == 4
     for _, log in logs.items():
         assert (
@@ -226,7 +227,7 @@ async def test_pod_from_yaml(k8s_cluster, docker_image):
                     ],
                     "image": docker_image,
                     "imagePullPolicy": "IfNotPresent",
-                    "name": "dask-worker",
+                    "name": KUBECLUSTER_WORKER_CONTAINER_NAME,
                 }
             ]
         },
@@ -274,7 +275,7 @@ async def test_pod_expand_env_vars(k8s_cluster, docker_image):
                         ],
                         "image": "${FOO_IMAGE}",
                         "imagePullPolicy": "IfNotPresent",
-                        "name": "dask-worker",
+                        "name": KUBECLUSTER_WORKER_CONTAINER_NAME,
                     }
                 ]
             },
@@ -308,7 +309,7 @@ async def test_pod_template_dict(docker_image):
                     "command": None,
                     "image": docker_image,
                     "imagePullPolicy": "IfNotPresent",
-                    "name": "dask-worker",
+                    "name": KUBECLUSTER_WORKER_CONTAINER_NAME,
                 }
             ]
         },
@@ -349,7 +350,7 @@ async def test_pod_template_minimal_dict(k8s_cluster, docker_image):
                     "command": None,
                     "image": docker_image,
                     "imagePullPolicy": "IfNotPresent",
-                    "name": "worker",
+                    "name": KUBECLUSTER_WORKER_CONTAINER_NAME,
                 }
             ]
         }
@@ -365,11 +366,20 @@ async def test_pod_template_minimal_dict(k8s_cluster, docker_image):
 
 @pytest.mark.asyncio
 async def test_pod_template_from_conf(docker_image):
-    spec = {"spec": {"containers": [{"name": "some-name", "image": docker_image}]}}
+    spec = {
+        "spec": {
+            "containers": [
+                {"name": KUBECLUSTER_WORKER_CONTAINER_NAME, "image": docker_image}
+            ]
+        }
+    }
 
     with dask.config.set({"kubernetes.worker-template": spec}):
         async with KubeCluster(**cluster_kwargs) as cluster:
-            assert cluster.pod_template.spec.containers[0].name == "some-name"
+            assert (
+                cluster.pod_template.spec.containers[0].name
+                == KUBECLUSTER_WORKER_CONTAINER_NAME
+            )
 
 
 @pytest.mark.asyncio
@@ -405,7 +415,7 @@ async def test_reject_evicted_workers(cluster):
     await cluster.core_api.create_namespaced_pod_eviction(
         (await worker.describe_pod()).metadata.name,
         (await worker.describe_pod()).metadata.namespace,
-        kubernetes.client.V1beta1Eviction(
+        kubernetes.client.V1Eviction(
             delete_options=kubernetes.client.V1DeleteOptions(grace_period_seconds=300),
             metadata=(await worker.describe_pod()).metadata,
         ),
@@ -573,7 +583,7 @@ async def test_automatic_startup(k8s_cluster, docker_image):
                         "1",
                     ],
                     "image": docker_image,
-                    "name": "dask-worker",
+                    "name": KUBECLUSTER_WORKER_CONTAINER_NAME,
                 }
             ]
         },
